pub fn percent<Input: Into<f64> + Copy, T: FromPercent>(percent: Input) -> TExpand description
Returns a value of the inferred type which represent a percentage
pub fn percent<Input: Into<f64> + Copy, T: FromPercent>(percent: Input) -> TReturns a value of the inferred type which represent a percentage